@@ -24,6 +24,8 @@ type SyncOptions struct {
 	WaitRetries int
 	// WaitForJobs is the wait for jobs flag
 	WaitForJobs bool
+	// Timeout is the timeout flag in seconds
+	Timeout int
 	// ReuseValues is true if the helm command should reuse the values
 	ReuseValues bool
 	// ResetValues is true if helm command should reset values to charts' default
@@ -124,6 +126,11 @@ func (t *SyncImpl) WaitForJobs() bool {
 	return t.SyncOptions.WaitForJobs
 }
 
+// Timeout returns the timeout
+func (t *SyncImpl) Timeout() int {
+	return t.SyncOptions.Timeout
+}
+
 // ReuseValues returns the ReuseValues.
 func (t *SyncImpl) ReuseValues() bool {
 	if !t.ResetValues() {
